@@ -23,11 +23,7 @@
 #include "gispyspatialindex.h"
 #include "Python.h"
 
-#ifdef _MSC_VER
-#include "SpatialIndex.h"
-#else
-#include <spatialindex/SpatialIndex.h>
-#endif
+#include "sidx_config.h"
 
 using namespace SpatialIndex;
 
@@ -60,10 +56,9 @@ private:
     PyObject *ids;
 };
 
-
 extern "C"
 GISPySpatialIndex *
-RtreeIndex_new(char* filename, unsigned long nPageLength, int load)
+RtreeIndex_new(char* filename, uint32_t nPageLength, int load)
 {
     if (!filename)
         return new GISPySpatialIndex;
